@@ -1,12 +1,13 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.100001';
+$BalanceOfPower::Commands::VERSION = '0.110000';
 use v5.10;
 use Moo;
 use IO::Prompter;
 use Term::ANSIColor;
 use BalanceOfPower::Constants ":all";
-use BalanceOfPower::Utils qw(next_turn get_year_turns compare_turns);
+use BalanceOfPower::Utils qw(next_turn get_year_turns compare_turns evidence_text);
 use BalanceOfPower::Commands::Plain;
+use BalanceOfPower::Commands::NoArgs;
 use BalanceOfPower::Commands::DeclareWar;
 use BalanceOfPower::Commands::TargetRoute;
 use BalanceOfPower::Commands::MilitarySupport;
@@ -45,16 +46,16 @@ sub init
 {
     my $self = shift;
     my $command = 
-        BalanceOfPower::Commands::Plain->new( name => "BUILD TROOPS",
+        BalanceOfPower::Commands::NoArgs->new( name => "BUILD TROOPS",
                                               world => $self->world,
                                               allowed_at_war => 1 );
     push @{$self->commands}, $command; 
     $command = 
-        BalanceOfPower::Commands::Plain->new( name => "LOWER DISORDER",
+        BalanceOfPower::Commands::NoArgs->new( name => "LOWER DISORDER",
                                               world => $self->world );
     push @{$self->commands}, $command; 
     $command = 
-        BalanceOfPower::Commands::Plain->new( name => "ADD ROUTE",
+        BalanceOfPower::Commands::NoArgs->new( name => "ADD ROUTE",
                                               world => $self->world );
     push @{$self->commands}, $command; 
     $command =
@@ -67,7 +68,7 @@ sub init
                                                  world => $self->world );
     push @{$self->commands}, $command; 
     $command =
-        BalanceOfPower::Commands::Plain->new( name => "BOOST PRODUCTION",
+        BalanceOfPower::Commands::NoArgs->new( name => "BOOST PRODUCTION",
                                                     world => $self->world,
                                                     production_limit => { '<' => EMERGENCY_PRODUCTION_LIMIT } );
     push @{$self->commands}, $command; 
@@ -113,7 +114,7 @@ WELCOME
     {
         $self->world->player_nation("Italy");
         $self->world->player("PlayerOne");
-        $auto_years = 20;
+        $auto_years = 10;
     }
     else
     {
@@ -227,7 +228,9 @@ COMMANDS
 
     my $result = { status => 0 };
 
-    if($query eq "quit") { $self->active(0); $result = 1 }
+    $query = lc $query;
+
+    if($query eq "quit") { $self->active(0); $result = { status => 1 }; }
     elsif($query eq "nations")
     {
         $query = prompt "?", -menu=>$self->world->nation_names;
@@ -282,55 +285,61 @@ COMMANDS
     }
     elsif($query =~ /^distance (.*)-(.*)$/)
     {
-        if($self->verify_nation($1) && $self->verify_nation($2))
+        my $n1 = $self->world->correct_nation_name($1);
+        my $n2 = $self->world->correct_nation_name($2);
+        if($self->verify_nation($n1) && $self->verify_nation($n2))
         {
-            say $self->world->print_distance($1, $2);
+            say $self->world->print_distance($n1, $n2);
             $result = { status => 1 };
         }
     }
     elsif($query =~ /^((.*) )?borders$/)
     {
-        my $input_nation = $2;
+        my $input_nation = $self->world->correct_nation_name($2);
         if($input_nation)
         {
             $self->nation($input_nation);
         }
-        if($self->nation)
+        if(! $self->nation)
         {
-            #print $self->world->print_borders($self->nation);
-            print $self->world->print_borders_analysis($self->nation);
+            $self->nation($self->world->player_nation);
         }
+        #print $self->world->print_borders($self->nation);
+        print $self->world->print_borders_analysis($self->nation);
         $result = { status => 1 };
     }
     elsif($query =~ /^((.*) )?near$/)
     {
-        my $input_nation = $2;
+        my $input_nation = $self->world->correct_nation_name($2);
         if($input_nation)
         {
             $self->nation($input_nation);
         }
-        if($self->nation)
+        if(! $self->nation)
         {
-           print $self->world->print_near_nations($self->nation);
+            $self->nation($self->world->player_nation);
         }
+        #print $self->world->print_near_nations($self->nation);
+        print $self->world->print_near_analysis($self->nation);
         $result = { status => 1 };
     }
     elsif($query =~ /^((.*) )?relations$/)
     {
-        my $input_nation = $2;
+        my $input_nation = $self->world->correct_nation_name($2);
         if($input_nation)
         {
             $self->nation($input_nation);
         }
-        if($self->nation)
+        if(! $self->nation)
         {
-            print $self->world->print_diplomacy($self->nation);
+            $self->nation($self->world->player_nation);
         }
+        print $self->world->print_diplomacy($self->nation);
         $result = { status => 1 };
     }
     elsif($query =~ /^((.*) )?events( ((\d+)(\/\d+)?))?$/)
     {
-        my $input_nation = $2;
+        my $input_nation = $self->world->correct_nation_name($2);
         my $input_year = $4;
         $input_year ||= undef;
         if($input_nation)
@@ -367,7 +376,7 @@ COMMANDS
     }
     elsif($query =~ /^((.*) )?status$/)
     {
-        my $input_nation = $2;
+        my $input_nation = $self->world->correct_nation_name($2);
         if($input_nation)
         {
             $query = $input_nation;
@@ -382,23 +391,25 @@ COMMANDS
     }
     elsif($query =~ /^((.*) )?history$/)
     {
-        my $input_nation = $2;
+        my $input_nation = $self->world->correct_nation_name($2);
         if($input_nation)
         {
             $self->nation($input_nation);
         }
-        if($self->nation)
+        if(! $self->nation)
         {
-            print $self->world->print_nation_statistics($self->nation, $self->world->first_year, $self->world->current_year);
+            $self->nation($self->world->player_nation);
         }
+        print $self->world->print_nation_statistics($self->nation, $self->world->first_year, $self->world->current_year);
         $result = { status => 1 };
     }
     else
     {
-        if($self->verify_nation($query)) #it's a nation
+        my $nation_query = $self->world->correct_nation_name($query);
+        if($self->verify_nation($nation_query)) #it's a nation
         { 
-            print $self->world->print_nation_actual_situation($query);
-            $self->nation($query);
+            print $self->world->print_nation_actual_situation($nation_query);
+            $self->nation($nation_query);
             $result = { status => 1 };
         }
         else
@@ -437,6 +448,7 @@ sub verify_nation
 {
     my $self = shift;
     my $query = shift;
+    return 0 if (! $query);
     my @good_nation = grep { $query  =~ /^$_$/ } @{$self->world->nation_names};
     return @good_nation > 0;
 }
@@ -474,7 +486,7 @@ sub interact
         if($result->{status} == 1)
         {
             $self->world->elaborate_turn();
-            say $self->world->print_formatted_turn_events($self->world->current_year);
+            say evidence_text($self->world->print_formatted_turn_events($self->world->current_year), $self->world->player_nation);
             next;
         }
         $result = $self->report_commands();
