@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands::Role::Command;
-$BalanceOfPower::Commands::Role::Command::VERSION = '0.100001';
+$BalanceOfPower::Commands::Role::Command::VERSION = '0.110000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -66,7 +66,8 @@ sub extract_argument
     my $self = shift;
     my $query = shift;
     my $extract = shift;
-    $extract =1 if(! defined $extract);
+    $query = uc $query; #Commands are always all caps
+    $extract = 1 if(! defined $extract);
     my $name = $self->name;
     if($query =~ /^$name( (.*))?$/)
     {
@@ -114,7 +115,7 @@ sub execute
 {
     my $self = shift;
     my $query = shift;
-    return { status => 1, command => $query };
+    return { status => 1, command => uc $query };
 }
 
 sub print
