@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands::TargetNation;
-$BalanceOfPower::Commands::TargetNation::VERSION = '0.100001';
+$BalanceOfPower::Commands::TargetNation::VERSION = '0.110000';
 use Moo;
 use v5.10;
 use IO::Prompter;
@@ -23,11 +23,8 @@ sub execute
     my $self = shift;
     my $query = shift;
     my $nation = shift;
-    if($self->good_target($nation))
-    {
-        return { status => 1, command => $self->name . " " . $nation };
-    }
     my $argument = $self->extract_argument($query);
+    $argument = $self->world->correct_nation_name($argument);
     if($argument)
     {
         if($self->good_target($argument))
@@ -39,6 +36,13 @@ sub execute
             say "Bad argument provided: $argument";
         }
     }
+    else
+    {
+        if($self->good_target($nation))
+        {
+            return { status => 1, command => $self->name . " " . $nation };
+        }
+    }
     my @nations = $self->get_available_targets;
     if(@nations > 0)
     {
