@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation;
-$BalanceOfPower::Nation::VERSION = '0.100001';
+$BalanceOfPower::Nation::VERSION = '0.110000';
 use strict;
 use v5.10;
 
@@ -245,7 +245,7 @@ sub military_advisor
             {
                 my $enemy = $world->get_nation($c->destination($self->name));
                 next if $world->war_busy($enemy->name);
-                if($self->good_prey($enemy, $world, $c->factor))
+                if($self->good_prey($enemy, $world, $c->crisis_level))
                 {
                     if($world->in_military_range($self->name, $enemy->name))
                     {
@@ -503,9 +503,10 @@ sub add_internal_disorder
 {
     my $self = shift;
     my $disorder = shift;
-    $disorder = int($disorder * 100) / 100;
     my $actual_disorder = $self->internal_disorder_status;
-    $self->internal_disorder($self->internal_disorder + $disorder);
+    my $new_disorder_data = $self->internal_disorder + $disorder;
+    $new_disorder_data = int($new_disorder_data * 100) / 100;
+    $self->internal_disorder($new_disorder_data);
     if($self->internal_disorder > 100)
     {
         $self->internal_disorder(100);
@@ -624,7 +625,6 @@ sub occupation
     $world->reset_influences($self->name);
     $world->reset_supports($self->name);
     $world->reset_crises($self->name);
-
 }
 
 sub build_troops
