@@ -1,5 +1,5 @@
 package BalanceOfPower::Relations::Friendship;
-$BalanceOfPower::Relations::Friendship::VERSION = '0.100001';
+$BalanceOfPower::Relations::Friendship::VERSION = '0.110000';
 use strict;
 use v5.10;
 
@@ -10,6 +10,10 @@ use Term::ANSIColor;
 has factor => (
     is => 'rw'
 );
+has crisis_level => (
+    is => 'rw',
+    default => 0
+);
 with 'BalanceOfPower::Relations::Role::Relation';
 
 sub status
@@ -54,32 +58,75 @@ sub status_color
     }
 }
 
-
 sub print 
 {
     my $self = shift;
     my $from = shift;
+    my $second_node;
+    my $out;
     if($from)
     {
         if($from eq $self->node1)
         {
-            return $self->status_color . $from . " <--> " . $self->node2 . " [" . $self->factor . " " . $self->status . "]" . color("reset");
+            $second_node = $self->node2;
         }
         elsif($from eq $self->node2)
         {
-            return $self->status_color . $from . " <--> " . $self->node1 . " [" . $self->status . "]" . color("reset");
+            $second_node = $self->node1;
         }
     }
     else
     {
-        return $self->status_color . $self->node1 . " <--> " . $self->node2 . " [" . $self->status . "]" . color("reset");
+        $from = $self->node1;
+        $second_node = $self->node2;
     }
+    $out = $self->status_color . $from . " <--> " . $second_node . " [" . $self->factor . " " . $self->status . "]";
+    if($self->crisis_level > 0)
+    {
+        $out .= " " . $self->print_crisis_bar();
+    }
+    $out .= color("reset");
+    return $out;
 }
 sub print_status
 {
     my $self = shift;
     return $self->status_color . $self->status . color("reset");
 }
+sub print_crisis
+{
+    my $self = shift;
+    if($self->crisis_level > 0)
+    {
+        return $self->node1 . " <-> " . $self->node2 . " (" . $self->crisis_level . ")";
+    }
+    else
+    {
+        return "";
+    }
+}
+sub print_crisis_bar
+{
+    my $self = shift;
+    my $out = "";
+    if($self->crisis_level > 0)
+    {
+        $out .= $self->status_color . "[";
+        for(my $i = 0; $i < CRISIS_MAX_FACTOR; $i++)
+        {
+            if($i < $self->crisis_level)
+            {
+                $out .= "*";
+            }
+            else
+            {
+                $out .= " ";
+            }
+        }
+        $out .= "]" . color("reset");
+    }
+    return $out;
+}
 
 
 sub change_factor
@@ -91,4 +138,26 @@ sub change_factor
     $self->factor($new_factor);
 }
 
+sub escalate_crisis
+{
+    my $self = shift;
+    $self->crisis_level($self->crisis_level() + 1);
+}
+sub cooldown_crisis
+{
+    my $self = shift;
+    $self->crisis_level($self->crisis_level() - 1);
+}
+sub is_crisis
+{
+    my $self = shift;
+    return $self->crisis_level > 0;
+}
+sub is_max_crisis
+{
+    my $self = shift;
+    return $self->crisis_level = CRISIS_MAX_FACTOR;
+}
+
+
 1;
