@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Analyst;
-$BalanceOfPower::Role::Analyst::VERSION = '0.100001';
+$BalanceOfPower::Role::Analyst::VERSION = '0.110000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -7,7 +7,9 @@ use Term::ANSIColor;
 use BalanceOfPower::Utils qw( as_title as_subtitle );
 
 requires 'diplomacy_exists';
+requires 'get_borders';
 requires 'supported';
+requires 'exists_military_support';
 requires 'near_nations';
 requires 'routes_for_node';
 requires 'get_allies';
@@ -77,7 +79,7 @@ sub print_nation_actual_situation
         if(@crises)
         {
             my $c = shift @crises;
-            $crisis_text = $c->print;
+            $crisis_text = $c->print_crisis;
         }
         my $war_text = "";
         if(@wars)
@@ -101,7 +103,9 @@ sub print_borders_analysis
     foreach my $b (@borders)
     {
         $out .= as_title("# " . $b  . " #") . "\n";
-        $out .= "  Relations: " . $self->diplomacy_exists($nation, $b)->print_status() . "\n";
+        my $rel = $self->diplomacy_exists($nation, $b);
+        $out .= "  Relations: " . $rel->print_status() . " " . 
+                                  $rel->print_crisis_bar() . "\n";
         my @supps = $self->supported($b);
         if(@supps)
         {
@@ -109,11 +113,57 @@ sub print_borders_analysis
             foreach my $ms (@supps)
             {
                 my $supporter = $ms->start($b);
-                $out .= "    $supporter (" . $self->diplomacy_exists($nation, $supporter)->print_status() . ")\n";
+                my $sup_rel = $self->diplomacy_exists($nation, $supporter);
+                $out .= "    $supporter (" . $sup_rel->print_status();
+                if($sup_rel->is_crisis())
+                {
+                    $out .= " " . $sup_rel->print_crisis_bar;
+                } 
+                $out .= ")\n";
             }
         }
     }
     return $out;
 }
+sub print_near_analysis
+{
+    my $self = shift;
+    my $nation = shift;
+    my @near = $self->near_nations($nation, 0);
+    my $out = "";
+    foreach my $b (@near)
+    {
+        $out .= as_title($b) . " " . $self->diplomacy_exists($nation, $b)->print_status();
+        if(! $self->border_exists($nation, $b))
+        {
+            if($self->exists_military_support($nation, $b))
+            {
+                $out .= " (supported)\n";
+            }
+            else
+            {
+                $out .= "\n";
+                my @foreign_borders = $self->get_borders($b);
+                foreach my $fb (@foreign_borders)
+                {
+                    my $other_n = $fb->destination($b);
+                    my @sups = $self->supported($other_n);
+                    for(@sups)
+                    {
+                        if($_->start($other_n) eq $nation)
+                        {
+                            $out .= "    Military support from: $other_n\n";   
+                        }
+                    }
+                }
+            }
+        }
+        else
+        {
+            $out .= "\n";
+        }
+    }
+    return $out;
+}
 
 1;
