@@ -1,5 +1,5 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.100001';
+$BalanceOfPower::World::VERSION = '0.110000';
 use strict;
 use v5.10;
 
@@ -73,6 +73,7 @@ with 'BalanceOfPower::Role::Diplomat';
 with 'BalanceOfPower::Role::Supporter';
 with 'BalanceOfPower::Role::Merchant';
 with 'BalanceOfPower::Role::Warlord';
+with 'BalanceOfPower::Role::CrisisManager';
 with 'BalanceOfPower::Role::Historian';
 with 'BalanceOfPower::Role::Analyst';
 
@@ -90,6 +91,17 @@ sub get_nation
         return undef;
     }
 }
+sub correct_nation_name
+{
+    my $self = shift;
+    my $nation = shift;
+    return undef if(! $nation);
+    for(@{$self->nation_names})
+    {
+        return $_ if(uc $_ eq uc $nation);
+    }
+    return undef;
+}
 sub get_player_nation
 {
     my $self = shift;
@@ -580,7 +592,7 @@ sub warfare
 sub register_global_data
 {
     my $self = shift;
-    my $crises = $self->crises->all();
+    my $crises = $self->get_all_crises();
     my $wars = $self->wars->all();
     $self->set_statistics_value(undef, 'crises', $crises);
     $self->set_statistics_value(undef, 'wars', $wars);
